spannertools.make_solid_text_spanner_with_nib
=============================================

.. autofunction:: abjad.tools.spannertools.make_solid_text_spanner_with_nib.make_solid_text_spanner_with_nib
